<?php

/**
 * @file
 * Provides form and submit handlers for the Keyboard Shortcut Utility.
 */

/*
 * Form callback for binding item.
 */
function keyboard_shortcut_binding_form(&$form, &$form_state) {
  $binding = $form_state['item'];

  $form['shortcut'] = array(
    '#title' => t('Keyboard shortcut'),
    '#type' => 'textfield',
    '#default_value' => $binding->shortcut,
    '#description' => t("Enter in a <strong>single</strong> key binding. Example: <code>ctrl+k</code> or <code>command+shift+a</code>. !link",
      array('!link' => l('Binding documentation.', 'http://craig.is/killing/mice', array('attributes' => array('target' => '_blank'))))),
    '#required' => TRUE,
    '#size' => 30,
  );
  // @TODO Decouple into another function.
  $action_options = array();

  ctools_include('plugins');
  $actions = ctools_get_plugins('keyboard_shortcut', 'action');

  foreach ($actions as $id => $action) {
    $action_options[$id] = $action['label'];
  }

  $form['shortcut_type'] = array(
    '#type' => 'select',
    '#title' => t('Action type'),
    '#default_value' => $binding->shortcut_type,
    '#options' => $action_options,
  );

  $form['shortcut_action_data'] = array(
    '#type' => 'fieldset',
    '#title' => t('Details'),
  );


  // @TODO Decouple into another function.
  $form_action = array();

  foreach ($actions as $id => $action) {
    // Get action form.
    $action_get_form = $action['handler']->form($form, $form_state, $binding);
    if (!empty($action_get_form)) {

      $form_action['shortcut_action_' . $id . '_wrapper'] = array(
        '#type' => 'fieldset',
        '#title' => $action['label'],
        '#states' => array(
          'visible' => array(
            ':input[name=shortcut_type]' => array('value' => $id),
          ),
        ),
      );
      $form_action['shortcut_action_' . $id . '_wrapper'] += $action_get_form;
    }
  }

  // Attached form from action method.
  if (!empty($form_action)) {
    $form['shortcut_action_data'] += $form_action;
  }

  return $form;
}

/*
 * Submit callback for binding item form.
 *
 * @see keyboard_shortcut_binding_form();
 */
function keyboard_shortcut_binding_form_submit($form, &$form_state) {

  $selected_action = $form_state['values']['shortcut_type'];

  ctools_include('plugins');
  $actions = ctools_get_plugins('keyboard_shortcut', 'action');


  if (!empty($actions[$selected_action])) {

    $action = $actions[$selected_action];

    $action_data = $action['handler']->submit($form, $form_state);
    if (!empty($action_data)) {
      $form_state['item']->shortcut_action_data = $action_data;
    }
  }
}