<?php

class keyboardShortcutJsAction implements keyboardShortcutActionInterface {

  public function form($form, &$form_state, $binding) {
    $form = array();

    $data = $binding->shortcut_action_data;

    $form['js_callback'] = array(
      '#type' => 'textfield',
      '#title' => t('JavaScript callback'),
      '#default_value' => !empty($data['js_callback']) ? $data['js_callback'] : '',
      '#description' => t("Enter in a function for the callback. DO NOT add <code>();</code> to the end. Example: <code>my_callback_function</code>"),
      '#element_validate' => array('_keyboard_shortcut_js_action_callback'),
    );

    return $form;
  }

  public function render($bindings) {
    $js_bindings = array();

    foreach($bindings as $binding) {
      $js_bindings[$binding->name] = array(
        'name' => $binding->name,
        'shortcut' => $binding->shortcut,
        'shortcut_type' => $binding->shortcut_type,
      );

      // Process action data array.
      $data = $binding->shortcut_action_data;
      if (is_array($data) && !empty($data['js_callback'])) {
        $js_bindings[$binding->name] += array(
          'js_callback' => $data['js_callback'],
        );
      }
    }

    drupal_add_js(array('keyboardShortcut' => array('js_callback' => $js_bindings)), 'setting');

    $path = drupal_get_path('module', 'keyboard_shortcut');
    drupal_add_js($path . '/js/js_action.js');
  }

  public function submit($form, &$form_state) {
    $data = array();

    $value = $form_state['values']['js_callback'];

    if (!empty($value)) {
      $data = array(
        'js_callback' => $value,
      );
    }
    return $data;
  }

}

function _keyboard_shortcut_js_action_callback($element, &$form_state) {
  $type = $form_state['values']['shortcut_type'];
  if ($type == 'js_action') {
    if (empty($element['#value'])) {
      form_error($element, t('Please enter in a JavaScript callback.'));
    }
  }
}

$plugin = array(
  'name' => 'js_action',
  'label' => t('Execute JavaScript callback'),
  'handler' => new keyboardShortcutJsAction(),
);


