<?php

class keyboardShortcutUrlAction implements keyboardShortcutActionInterface {

  public function form($form, &$form_state, $binding) {
    $form = array();

    $data = $binding->shortcut_action_data;

    $form['goto_url'] = array(
      '#type' => 'textfield',
      '#title' => t('Internal or external URL'),
      '#default_value' => !empty($data['goto_url']) ? $data['goto_url'] : '',
      '#description' => t("Enter in an internal or external URL. Example: <code>node/add</code> for an internal URL or <code>http://drupal.org</code> for an external."),
      '#element_validate' => array('_keyboard_shortcut_url_action_callback'),
    );

    return $form;
  }

  public function render($bindings) {
    $js_bindings = array();

    foreach($bindings as $binding) {
      $js_bindings[$binding->name] = array(
        'name' => $binding->name,
        'shortcut' => $binding->shortcut,
        'shortcut_type' => $binding->shortcut_type,
      );

      // Process action data array.
      $data = $binding->shortcut_action_data;
      if (is_array($data) && !empty($data['goto_url'])) {

        $path = url($data['goto_url'], array('absolute' => TRUE));

        $js_bindings[$binding->name] += array(
          'goto_url' => $path,
        );
      }
    }

    drupal_add_js(array('keyboardShortcut' => array('goto_url' => $js_bindings)), 'setting');

    $path = drupal_get_path('module', 'keyboard_shortcut');
    drupal_add_js($path . '/js/url_action.js');
  }

  public function submit($form, &$form_state) {
    $data = array();

    $value = $form_state['values']['goto_url'];

    if (!empty($value)) {
      $data = array(
        'goto_url' => $value,
      );
    }
    return $data;
  }
}

function _keyboard_shortcut_url_action_callback($element, &$form_state) {
  $type = $form_state['values']['shortcut_type'];
  if ($type == 'url_action') {
    if (empty($element['#value'])) {
      form_error($element, t('Please enter in an internal or external URL.'));
    }
  }
}

$plugin = array(
  'name' => 'url_action',
  'label' => t('Go to URL'),
  'handler' => new keyboardShortcutUrlAction(),
);